# pgdumplib

Python 3 library for reading and writing [pg_dump](https://www.postgresql.org/docs/current/app-pgdump.html) files using the custom format.

[![Version](https://img.shields.io/pypi/v/pgdumplib.svg)](https://pypi.python.org/pypi/pgdumplib)
[![License](https://img.shields.io/pypi/l/pgdumplib.svg)](https://github.com/gmr/pgdumplib/blob/master/LICENSE)

## Installation

```bash
pip install pgdumplib
```

## Documentation

- [API Reference](api.md)
- [Constants](constants.md)
- [Converters](converters.md)
- [Exceptions](exceptions.md)
- [Examples](examples.md)
